Ace Kitchen Sink
Author: Fabian Jakobs

Document |
Mode |
Split |
Theme |
Font Size |
Code Folding |
Key Binding |
Soft Wrap |
Full Line Selection |
Highlight Active Line |
Show Invisibles |
Show Indent Guides |
Persistent HScroll | VScroll
Animate scrolling |
Show Gutter |
Show Print Margin |
Use Soft Tab |
Highlight selected word |
Enable Behaviours |
Fade Fold Widgets |
Enable Elastic Tabstops |
Incremental Search |
Show token info |
Read-only |
Scroll Past End |